from setuptools import setup

setup(name='distributions9989',
      version='0.1',
      description='Gaussian and Binomial distributions ',
      packages=['distributions9989'],
      zip_safe=False)
